@@ -23,12 +23,5 @@ my %conf  = (
 	config_file	=> 'cpansmoke.ini',
 );
 
-my @list = qw(
-);
-
-my $smoker = CPAN::YACSmoke->new(%conf);
-
-$smoker->mark();
-#$smoker->mark("$_")			for(@list);
-#$smoker->mark("$_",'none')	for(@list);
-#$smoker->excluded();
+mark(\%conf);
+#excluded(\%conf);
